@@ -17,6 +17,14 @@ class Blather():
         self.model.to(self.device)
     
     def read(self, data, epochs=1, batch_size = 4):
+
+        # We expect data to be passed as a list of strings representing sentences, we can add in a capability to read a .txt file 
+        if isinstance(data,str):
+            if data[-2:] == "txt":
+                with open(data, "r") as file:
+                    content = file.read().replace('\n','')
+                data = list(map(str.strip, content.split(".")))
+
         dataset = self.GPT2Dataset(data, tokenizer=self.tokenizer, max_length=103)
 
         train_size = int(0.9 * len(dataset))
@@ -77,11 +85,12 @@ class Blather():
             self.model.train()
 
             for step, batch in enumerate(train_dataloader):
-                if step == 0:
-                    start = time.time()
-                if step == 1:
-                    total_time_estimate = round((time.time()-start) * (total_steps-1)/60)
-                    print("Estimated Training time of " + str(total_time_estimate) + " minutes ")
+                if epoch_i == 0:
+                    if step == 0:
+                        start = time.time()
+                    if step == 1:
+                        total_time_estimate = round((time.time()-start) * epochs * (total_steps-1)/60)
+                        print("Estimated Training time of " + str(total_time_estimate) + " minutes ")
                 b_input_ids = batch[0].to(self.device)
                 b_labels = batch[0].to(self.device)
                 b_masks = batch[1].to(self.device)
